@@ -1,5 +1,5 @@
 use {
-    crate::{errors::*, state::*},
+    crate::{errors::ErrorCode, state::*},
     anchor_lang::prelude::*,
     cardinal_token_manager::state::{TokenManager, TokenManagerState},
 };
@@ -10,8 +10,9 @@ pub struct InitIx {
     pub expiration: Option<i64>,
     pub extension_payment_amount: Option<u64>,
     pub extension_duration_seconds: Option<u64>,
-    pub payment_mint: Option<Pubkey>,
+    pub extension_payment_mint: Option<Pubkey>,
     pub max_expiration: Option<i64>,
+    pub disable_partial_extension: Option<bool>
 }
 
 #[derive(Accounts)]
@@ -32,20 +33,15 @@ pub struct InitCtx<'info> {
     system_program: Program<'info, System>,
 }
 
-pub fn handler(ctx: Context<InitCtx>, ix: InitIx) -> ProgramResult {
+pub fn handler(ctx: Context<InitCtx>, ix: InitIx) -> Result<()> {
     if ix.duration_seconds == None && ix.expiration == None {
-        return Err(ErrorCode::InvalidInstruction.into());
+        return Err(error!(ErrorCode::InvalidInstruction));
     } else if (ix.extension_payment_amount == None && ix.extension_duration_seconds != None)
         || (ix.extension_payment_amount != None && ix.extension_duration_seconds == None)
     {
-        return Err(ErrorCode::InvalidInstruction.into());
-    } else if ix.extension_payment_amount != None && ix.payment_mint == None {
-        return Err(ErrorCode::InvalidInstruction.into());
-    } else if ix.payment_mint != None
-        && ctx.accounts.token_manager.payment_mint != None
-        && ctx.accounts.token_manager.payment_mint.unwrap() != ix.payment_mint.unwrap()
-    {
-        return Err(ErrorCode::InvalidPaymentMint.into());
+        return Err(error!(ErrorCode::InvalidInstruction));
+    } else if ix.extension_payment_amount != None && ix.extension_payment_mint == None {
+        return Err(error!(ErrorCode::InvalidInstruction));
     }
     let time_invalidator = &mut ctx.accounts.time_invalidator;
     time_invalidator.bump = *ctx.bumps.get("time_invalidator").unwrap();
@@ -54,7 +50,8 @@ pub fn handler(ctx: Context<InitCtx>, ix: InitIx) -> ProgramResult {
     time_invalidator.expiration = ix.expiration;
     time_invalidator.extension_payment_amount = ix.extension_payment_amount;
     time_invalidator.extension_duration_seconds = ix.extension_duration_seconds;
-    time_invalidator.payment_mint = ix.payment_mint;
+    time_invalidator.extension_payment_mint = ix.extension_payment_mint;
     time_invalidator.max_expiration = ix.max_expiration;
+    time_invalidator.disable_partial_extension = ix.disable_partial_extension;
     return Ok(());
 }
